==> instancio-core-2.11.0-sources.jar: org/instancio/generators/NetSpecs.java <==
/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.instancio.generators;

import org.instancio.generator.specs.EmailSpec;
import org.instancio.generator.specs.URISpec;
import org.instancio.generator.specs.URLSpec;
import org.instancio.internal.generator.domain.internet.EmailGenerator;
import org.instancio.internal.generator.net.URIGenerator;
import org.instancio.internal.generator.net.URLGenerator;

import java.net.URI;
import java.net.URL;

/**
 * Provides generators for {@code java.net} classes.
 *
 * @since 2.6.0
 */
public final class NetSpecs {

    /**
     * Generates {@link URI} values.
     *
     * @return API builder reference
     * @since 2.6.0
     */
    public URISpec uri() {
        return new URIGenerator();
    }

    /**
     * Generates {@link URL} values.
     *
     * @return API builder reference
     * @since 2.6.0
     */
    public URLSpec url() {
        return new URLGenerator();
    }

    /**
     * Generates email addresses.
     *
     * @return API builder reference
     * @since 2.11.0
     */
    public EmailSpec email() {
        return new EmailGenerator();
    }
}

==> instancio-core-3.7.1-sources.jar: org/instancio/generators/NetSpecs.java <==
/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.instancio.generators;

import org.instancio.generator.specs.EmailSpec;
import org.instancio.generator.specs.Ip4Spec;
import org.instancio.generator.specs.URISpec;
import org.instancio.generator.specs.URLSpec;
import org.instancio.internal.generator.domain.internet.EmailGenerator;
import org.instancio.internal.generator.domain.internet.Ip4Generator;
import org.instancio.internal.generator.net.URIGenerator;
import org.instancio.internal.generator.net.URLGenerator;

import java.net.URI;
import java.net.URL;

/**
 * Provides generators for {@code java.net} classes.
 *
 * @since 2.6.0
 */
public final class NetSpecs {

    /**
     * Generates email addresses.
     *
     * @return API builder reference
     * @since 2.11.0
     */
    public EmailSpec email() {
        return new EmailGenerator();
    }

    /**
     * Generates IPv4 addresses.
     *
     * @return API builder reference
     * @since 2.12.0
     */
    public Ip4Spec ip4() {
        return new Ip4Generator();
    }

    /**
     * Generates {@link URI} values.
     *
     * @return API builder reference
     * @since 2.6.0
     */
    public URISpec uri() {
        return new URIGenerator();
    }

    /**
     * Generates {@link URL} values.
     *
     * @return API builder reference
     * @since 2.6.0
     */
    public URLSpec url() {
        return new URLGenerator();
    }

}
